The StarCityGames.com® Magic Spoiler Generator!
Description: Magic: the Gathering singles, strategy, and decks!
Keywords: Magic the gathering, Magic singles, Magic boxes, Magic decks, Magic cards, Magic strategy, mtg, spoiler, card list

Advanced Search
Name: |
Text: |
Flavor Text: |
Colors : |
All Colors | Blue | Red
White | Black | Green
Card Type |
All Types
Artifact Artifact Creature Artifact Land Basic Land Basic Snow Land Conspiracy Creature Eaturecray Emblem Enchant Creature Enchant Player Enchantment Enchantment Creature Hero Instant | Interrupt Land Land Creature Legendary Artifact Legendary Artifact Creature Legendary Creature Legendary Enchantment Legendary Enchantment Artifact Legendary Enchantment Creature Legendary Land Legendary Snow Land Ongoing Scheme Phenomenon Plane Planeswalker Scheme | Snow Artifact Snow Artifact Creature Snow Creature Snow Enchantment Snow Land Sorcery Summon Summon the Biggest, Baddest, Nastiest, Scariest Creature You'll Ever See Token Creature Tribal Artifact Tribal Enchantment Tribal Instant Tribal Sorcery Vanguard World Enchantment
Card Subtype CTRL+Left-click on the list to select multiple subtypes. |
| Creature Type CTRL+Left-click on the list to select multiple types. |
Converted Mana Cost: | to:
Power: |
Toughness: |
Rarity: | All Common Uncommon Rare Mythic Timeshifted Token Basic Land Promo
Format: |
Set(s): |
All Sets Core Sets Alpha Beta Unlimited 3rd Edition/Revised 4th Edition Chronicles 5th Edition 6th Edition 7th Edition 8th Edition 9th Edition 10th Edition Magic 2010 Magic 2011 Magic 2012 Magic 2013 Magic 2014 Magic 2015 Magic Origins Earlier Sets Arabian Nights Antiquities Legends The Dark Fallen Empires Homelands Ice Age Block Ice Age Alliances Coldsnap Coldsnap Theme Deck Reprints Mirage Block Mirage Visions Weatherlight Tempest Block Tempest Stronghold Exodus Saga Block Urza's Saga Urza's Legacy Urza's Destiny Masques Block Mercadian Masques Nemesis Prophecy Invasion Block Invasion Planeshift Apocalypse Odyssey Block Odyssey Torment Judgment | Onslaught Block Onslaught Legions Scourge Mirrodin Block Mirrodin Darksteel Fifth Dawn Kamigawa Block Champions of Kamigawa Betrayers of Kamigawa Saviors of Kamigawa Ravnica Block Ravnica: City of Guilds Guildpact Dissension Time Spiral Block Time Spiral Planar Chaos Future Sight Lorwyn Block Lorwyn Morningtide Shadowmoor Block Shadowmoor Eventide Shards of Alara Block Shards of Alara Conflux Alara Reborn Zendikar Block Zendikar Worldwake Rise of the Eldrazi Scars of Mirrodin Block Scars of Mirrodin Mirrodin Besieged New Phyrexia Innistrad Block Innistrad Dark Ascension Avacyn Restored Return to Ravnica Return To Ravnica Gatecrash Dragon's Maze Theros Block Theros Born of the Gods Journey Into Nyx Khans of Tarkir Block Khans of Tarkir Fate Reforged Dragons of Tarkir Battle for Zendikar Block Battle for Zendikar Oath of the Gatewatch Zendikar Expeditions | Portal and Starter Portal I Portal II Portal: Three Kingdoms Starter 1999 Starter 2000 Unglued Unglued Unhinged Box Sets Anthologies Archenemy Archenemy Scheme Battle Royale Beatdown Commander Commander Oversized Commander 2013 Commander 2013 Oversized Commander (2014 Edition) Commander 2014 Oversized Commander 2015 Commander 2015 Oversized Commander's Arsenal Commander's Arsenal Oversized Conspiracy Deckmasters DD: Ajani vs. Nicol Bolas DD: Divine vs. Demonic DD: Elspeth vs. Kiora DD: Elspeth vs. Tezzeret DD: Elves vs. Goblins DD: Garruk vs. Liliana DD: Heroes vs. Monsters DD: Izzet vs. Golgari DD: Jace vs. Chandra DD: Jace vs. Vraska DD: Knights vs. Dragons DD: Phyrexia vs. The Coalition DD: Sorin vs. Tibalt DD: Speed vs. Cunning DD: Venser vs. Koth DD: Zendikar vs. Eldrazi Duel Decks Anthology Duels of the Planeswalker From the Vault: Angels From the Vault: Annihilation From the Vault: Dragons From the Vault: Exiled From the Vault: Legends From the Vault: Realms From the Vault: Relics From the Vault: Twenty Modern Event Deck Modern Masters Modern Masters 2015 Edition Planechase Singles Planechase Planes Planechase 2012 Singles Planechase 2012 Planes & Phenomena Premium Deck Series: Fire & Lightning Premium Deck Series: Graveborn Premium Deck Series: Slivers Miscellaneous 6" x 9" Cards Alternate 4th Edition Foreign: Chinese (S) Foreign: Chinese (T) Foreign: French Foreign: German Foreign: Italian Foreign: Japanese Foreign: Korean Foreign: Portuguese Foreign: Russian Foreign: Spanish Lithographs Magic Original Art Magic Tip and Trick Cards Magic Token Cards Pro Player Cards Promo Cards Rarities and Misprints Vanguard Gold-Bordered Collectors' Edition International Edition
Price: | $ to $
On-Hand: | to:
Condition: | All Near Mint/Mint Slightly Played Moderately Played
Foil: |
Foreign: | Foreign and Non-Foreign Cards | No Foreign Cards | Foreign Cards Only
Artist: |
Sort By: | > > >
Display Style: | Complete (With Images) Checklist

ORGANIZED PLAY

- THIS Friday, December 11
- INVITATIONAL Las Vegas
- Invitational Qualifiers
- Somerville, NJ - The Only Game in Town
- THIS Saturday, December 12
- INVITATIONAL Las Vegas
- 5K Premier Invitational Qualifiers
- Chicago, IL - Pastimes
- East Windsor, CT - Ice Imports
- 1K Super Invitational Qualifiers
- Athens, AL - Static Age Games
- Invitational Qualifiers
- Athens, GA - Card Advantage
- Aurora, CO - All C's Gaming Arena
- Cayce, SC - Ready to Play Trading Cards
- Crestview, FL - GameMasters Guild
- Four Oaks, NC - Hobby Invasion
- Glen Burnie, MD - Games and Stuff
- Granite Falls, NC - Warlords Games
- Hatboro, PA - Stomping Grounds
- New Philadelphia, OH - MAD Bros
- Prairieville, LA - Gamers Paradise
- River Falls, WI - Game Quest
- Roanoke, VA - Star City Game Center
- San Antonio,TX - Dragon's Lair Comics and Fantasy
- Springfield, MO - Meta-Games Unlimited
- Temple, TX - The Card House
- Warner Robin, GA - Heroes and Villains
- GPT (IQ Prizes)
- Gatlinburg, TN - Gamers Link
- THIS Sunday, December 13
- INVITATIONAL Las Vegas
- 1K Super Invitational Qualifiers
- Columbia, MO - Magelings Games
- East Windsor, CT - Ice Imports
- Invitational Qualifiers
- Cary, NC - East Coast Gaming
- Dalton, GA - The Battlegrounds Games and Comics
- East Windsor, NJ - Gamer's Realm Hobby
- Falls Church, VA - Victory Comics
- Guatemala City, GT - Master Games
- Kingsport, TN - Mulligan's Gaming
- Lexington, KY - Legendary Games
- Lutherville/Timonium, MD - Titan Games and Hobbies
- New Holland, PA - Six Feet Under Games
- Roanoke, VA - Star City Game Center

- Tuesday, December 15
- Invitational Qualifiers
- Brooklyn, NY - Kings Games
- Thursday, December 17
- Invitational Qualifiers
- East Windsor, NJ - Gamer's Realm Hobby
- Friday, December 18
- Invitational Qualifiers
- Bronx, NY - The Lair
- Saturday, December 19
- 5K Premier Invitational Qualifiers
- Lansing, MI - Pastimes
- 1K Super Invitational Qualifiers
- Brooklyn, NY - Kings Games
- Indian Trail, NC - Be There Games
- San Diego, CA - San Diego Games and Comics
- Invitational Qualifiers
- Aurora, CO - All C's Gaming Arena
- Burnsville, MN - Legion Games
- Gaithersburg, MD - Play More Games
- Lexington, KY - Legendary Games
- Lutherville/Timonium, MD - Titan Games and Hobbies
- Mountain Grove, MO - Grove Gamers Guild
- West Hartford, CT - Voltage Gaming
- Sunday, December 20
- Invitational Qualifiers
- Boonton, NJ - Highlander Games & Comics
- Bristol, TN - MWO Games
- Columbus, OH - Comic Town
- Fountain, CO - J&J Games N Hobbies
- Glassboro, NJ - The Comic Book Store
- Granite Falls, NC - Warlords Games
- Lafayette, IN - Legendary Games
- San Salvador, SV - Naruto Ramen Cards and Games
- Springfield, VA - Curio Cavern
- West Hartford, CT - Voltage Gaming

STARCITYGAMES.COM® EVENTS

- Dec 11 -13: INVITATIONAL Las Vegas

ELITE QUALIFIERS

- THIS WEEK: See all Open Trials

EVENT FINDER

- Complete SCG Schedule - Coverage Archive

1 | JONATHAN N MORAWSKI | 275
2 | KEVIN JONES | 269
3 | ROSS MERRIAM | 257
4 | HUNTER NANCE | 251
5 | JOE LOSSETT | 250
6 | RUDY BRIKSZA | 244
7 | TODD ANDERSON | 243
8 | TOM ROSS | 237
9 | ERIC C HAWKINS | 235
10 | LOGAN G MIZE | 229
11 | CHRIS ANDERSEN | 218
12 | CALEB W SCHERER | 212
13 | JIM I DAVIS | 203
14 | MATTHEW M TICKAL | 203
15 | ANDREW JESSUP | 198
16 | DANNY JESSUP | 198

NEWS

- 12/4 Game Night in December, January and February!
- 12/4 SCG Season One Regionals on February 6!
- 11/13 Ryan Hoffman’s Judge Token!
- 11/6 Game Night in November, December and January!
- 10/22 Take Our IQ Player Survey!
- 10/19 SCGMobile® App Sunsets October 31st
- 10/5 Fall 2015 Creature Collection Products!
- 10/2 Get Alex Bastecki's Invitational Winner's Token!
- 10/2 Game Night in October, November, and December!
- 9/28 Battle for Zendikarrot Playmat Now on Sale!
- 9/21 Limited-Edition Brian Kibler “Wedding” Playmat!
- 9/14 Alex Bastecki’s Invitational Winner Token!
- View All News Items - Submit Magic News

DECKLISTS

- 12/05 SCG Open Denver, US
- 11/29 Invi Qualifier Columbus, US
- 11/29 SCG Premier IQ Somerset, US
- 11/28 Invi Qualifier Duluth, US
- 11/24 Invi Qualifier Brooklyn, US
- 11/22 SCG Super IQ San Diego, US
- 11/22 Invi Qualifier Charlotte, US
- 11/22 Invi Qualifier Dalton, US
- 11/22 Invi Qualifier Guatemala, GT
- 11/21 Invi Qualifier Arvada, US
- 11/21 Invi Qualifier Nanuet, US
- 11/21 Invi Qualifier Owensboro, US
- 11/21 Grand Prix Kobe, JP
- 11/21 SCG Open Kansas City, US
- 11/20 Invi Qualifier Bronx, US
- 11/19 Invi Qualifier Hartsdale, US
- 11/15 Invi Qualifier Conroe, US
- 11/15 Invi Qualifier Kent, US
- 11/15 SCG Super IQ Vacaville, US
- 11/15 Invi Qualifier Cockeysville, US

View More Standard Decks - Search Decklists

- 12/06 SCG Premier IQ Denver, US
- 11/29 SCG Premier IQ Somerset, US
- 11/29 SCG Premier IQ Somerset,
- 11/28 Invi Qualifier Bloomington, US
- 11/28 Invi Qualifier Burnsville, US
- 11/22 Invi Qualifier Eau Claire, US
- 11/22 Invi Qualifier West Hartford, US
- 11/22 Invi Qualifier Scarborough, US
- 11/22 Invi Qualifier Baton Rouge, US
- 11/22 Invi Qualifier Decatur, US
- 11/22 SCG Premier IQ Kansas City, US
- 11/21 Invi Qualifier Kingsport, US
- 11/21 Invi Qualifier Cary, US
- 11/21 Invi Qualifier Decatur, US
- 11/21 Invi Qualifier Dover, US
- 11/21 Grand Prix Pittsburgh, US
- 11/20 Invi Qualifier Newington, US
- 11/19 Invi Qualifier East Windsor, US
- 11/17 Invi Qualifier Brooklyn, US
- 11/15 Invi Qualifier Falls Church, US

View More Modern Decks - Search Decklists

- 12/06 SCG Premier IQ Denver, US
- 11/28 Invi Qualifier Findlay, US
- 11/28 SCG Open Somerset, US
- 11/27 Invi Qualifier Somerville, US
- 11/22 SCG Premier IQ Kansas City, US
- 11/21 Invi Qualifier Acton, US
- 11/08 Invi Qualifier Roanoke, US
- 11/08 SCG Premier IQ Philadelphia, US
- 11/07 Invi Qualifier East Windsor, US
- 11/07 Grand Prix Tacoma, US
- 11/01 Invi Qualifier Shakopee, US
- 11/01 Invi Qualifier East Windsor, US
- 11/01 SCG Premier IQ Dallas, US
- 10/30 Invi Qualifier Newington, US
- 10/24 SCG Open St. Louis, US
- 10/11 Invi Qualifier Aurora, US
- 10/11 SCG Premier IQ Atlanta, US
- 10/10 Invi Qualifier Columbia, US
- 10/04 Invi Qualifier Eau Claire, US
- 10/04 SCG Super IQ Columbia, US

View More Legacy Decks - Search Decklists
SOCIAL

StarCityGames.com® on Facebook

StarCityGames.com® on Twitter

Join the conversation

StarCityGames.com® on YouTube

Watch the best in Magic Video

WEEKLY NEWSLETTER

Exclusive Deals & Content Every Week